@@ -1,14 +1,10 @@
-// Copyright (C) 2008-2012 NICTA (www.nicta.com.au)
-// Copyright (C) 2008-2012 Conrad Sanderson
+// Copyright (C) 2008-2015 Conrad Sanderson
+// Copyright (C) 2008-2015 NICTA (www.nicta.com.au)
+// Copyright (C) 2012-2014 Ryan Curtin
 // 
-// This file is part of the Armadillo C++ library.
-// It is provided without any warranty of fitness
-// for any purpose. You can redistribute this file
-// and/or modify it under the terms of the GNU
-// Lesser General Public License (LGPL) as published
-// by the Free Software Foundation, either version 3
-// of the License or (at your option) any later version.
-// (see http://www.opensource.org/licenses for more info)
+// This Source Code Form is subject to the terms of the Mozilla Public
+// License, v. 2.0. If a copy of the MPL was not distributed with this
+// file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
 
 //! \addtogroup Mat
@@ -26,10 +22,6 @@ class Mat : public Base< eT, Mat<eT> >
   typedef eT                                elem_type;  //!< the type of elements stored in the matrix
   typedef typename get_pod_type<eT>::result pod_type;   //!< if eT is non-complex, pod_type is same as eT. otherwise, pod_type is the underlying type used by std::complex
   
-  static const bool is_col = false;
-  static const bool is_row = false;
-  
-  
   const uword  n_rows;    //!< number of rows in the matrix (read-only)
   const uword  n_cols;    //!< number of columns in the matrix (read-only)
   const uword  n_elem;    //!< number of elements in the matrix (read-only)
@@ -44,25 +36,40 @@ class Mat : public Base< eT, Mat<eT> >
   arma_aligned const eT* const mem;  //!< pointer to the memory used by the matrix (memory is read-only)
   
   protected:
-  arma_aligned eT mem_local[ arma_config::mat_prealloc ];
+  arma_align_mem eT mem_local[ arma_config::mat_prealloc ];
   
   
   public:
   
+  static const bool is_col = false;
+  static const bool is_row = false;
+  
   inline ~Mat();
   inline  Mat();
   
   inline Mat(const uword in_rows, const uword in_cols);
   
+  template<typename fill_type>
+  inline Mat(const uword in_rows, const uword in_cols, const fill::fill_class<fill_type>& f);
+  
   inline                  Mat(const char*        text);
   inline const Mat& operator=(const char*        text);
   
   inline                  Mat(const std::string& text);
   inline const Mat& operator=(const std::string& text);
   
+  inline                  Mat(const std::vector<eT>& x);
+  inline const Mat& operator=(const std::vector<eT>& x);
+  
   #if defined(ARMA_USE_CXX11)
   inline                  Mat(const std::initializer_list<eT>& list);
   inline const Mat& operator=(const std::initializer_list<eT>& list);
+  
+  inline                  Mat(const std::initializer_list< std::initializer_list<eT> >& list);
+  inline const Mat& operator=(const std::initializer_list< std::initializer_list<eT> >& list);
+  
+  inline                  Mat(Mat&& m);
+  inline const Mat& operator=(Mat&& m);
   #endif
   
   inline Mat(      eT* aux_mem, const uword aux_n_rows, const uword aux_n_cols, const bool copy_aux_mem = true, const bool strict = true);
@@ -100,8 +107,14 @@ class Mat : public Base< eT, Mat<eT> >
   inline const Mat& operator*=(const subview<eT>& X);
   inline const Mat& operator%=(const subview<eT>& X);
   inline const Mat& operator/=(const subview<eT>& X);
-
-  //inline explicit          Mat(const subview_cube<eT>& X);
+  
+  inline Mat(const subview_row_strans<eT>& X);  // subview_row_strans can only be generated by the Proxy class
+  inline Mat(const subview_row_htrans<eT>& X);  // subview_row_htrans can only be generated by the Proxy class
+  inline Mat(const        xvec_htrans<eT>& X);  //        xvec_htrans can only be generated by the Proxy class
+  
+  template<bool do_conj>
+  inline Mat(const xtrans_mat<eT,do_conj>& X);  //        xtrans_mat can only be generated by the Proxy class
+  
   inline                   Mat(const subview_cube<eT>& X);
   inline const Mat&  operator=(const subview_cube<eT>& X);
   inline const Mat& operator+=(const subview_cube<eT>& X);
@@ -109,8 +122,7 @@ class Mat : public Base< eT, Mat<eT> >
   inline const Mat& operator*=(const subview_cube<eT>& X);
   inline const Mat& operator%=(const subview_cube<eT>& X);
   inline const Mat& operator/=(const subview_cube<eT>& X);
-
-  //inline explicit          Mat(const diagview<eT>& X);
+  
   inline                   Mat(const diagview<eT>& X);
   inline const Mat&  operator=(const diagview<eT>& X);
   inline const Mat& operator+=(const diagview<eT>& X);
@@ -119,6 +131,14 @@ class Mat : public Base< eT, Mat<eT> >
   inline const Mat& operator%=(const diagview<eT>& X);
   inline const Mat& operator/=(const diagview<eT>& X);
   
+  inline                   Mat(const spdiagview<eT>& X);
+  inline const Mat&  operator=(const spdiagview<eT>& X);
+  inline const Mat& operator+=(const spdiagview<eT>& X);
+  inline const Mat& operator-=(const spdiagview<eT>& X);
+  inline const Mat& operator*=(const spdiagview<eT>& X);
+  inline const Mat& operator%=(const spdiagview<eT>& X);
+  inline const Mat& operator/=(const spdiagview<eT>& X);
+  
   template<typename T1> inline                   Mat(const subview_elem1<eT,T1>& X);
   template<typename T1> inline const Mat& operator= (const subview_elem1<eT,T1>& X);
   template<typename T1> inline const Mat& operator+=(const subview_elem1<eT,T1>& X);
@@ -135,6 +155,14 @@ class Mat : public Base< eT, Mat<eT> >
   template<typename T1, typename T2> inline const Mat& operator%=(const subview_elem2<eT,T1,T2>& X);
   template<typename T1, typename T2> inline const Mat& operator/=(const subview_elem2<eT,T1,T2>& X);
   
+  // Operators on sparse matrices (and subviews)
+  template<typename T1> inline explicit          Mat(const SpBase<eT, T1>& m);
+  template<typename T1> inline const Mat&  operator=(const SpBase<eT, T1>& m);
+  template<typename T1> inline const Mat& operator+=(const SpBase<eT, T1>& m);
+  template<typename T1> inline const Mat& operator-=(const SpBase<eT, T1>& m);
+  template<typename T1> inline const Mat& operator*=(const SpBase<eT, T1>& m);
+  template<typename T1> inline const Mat& operator%=(const SpBase<eT, T1>& m);
+  template<typename T1> inline const Mat& operator/=(const SpBase<eT, T1>& m);
   
   inline mat_injector<Mat> operator<<(const eT val);
   inline mat_injector<Mat> operator<<(const injector_end_of_row<>& x);
@@ -163,9 +191,18 @@ class Mat : public Base< eT, Mat<eT> >
   arma_inline       subview<eT> cols(const uword in_col1, const uword in_col2);
   arma_inline const subview<eT> cols(const uword in_col1, const uword in_col2) const;
   
+  inline            subview<eT> rows(const span& row_span);
+  inline      const subview<eT> rows(const span& row_span) const;
+  
+  arma_inline       subview<eT> cols(const span& col_span);
+  arma_inline const subview<eT> cols(const span& col_span) const;
+  
+  
   arma_inline       subview<eT> submat(const uword in_row1, const uword in_col1, const uword in_row2, const uword in_col2);
   arma_inline const subview<eT> submat(const uword in_row1, const uword in_col1, const uword in_row2, const uword in_col2) const;
   
+  arma_inline       subview<eT> submat(const uword in_row1, const uword in_col1, const SizeMat& s);
+  arma_inline const subview<eT> submat(const uword in_row1, const uword in_col1, const SizeMat& s) const;
   
   inline            subview<eT> submat    (const span& row_span, const span& col_span);
   inline      const subview<eT> submat    (const span& row_span, const span& col_span) const;
@@ -173,10 +210,27 @@ class Mat : public Base< eT, Mat<eT> >
   inline            subview<eT> operator()(const span& row_span, const span& col_span);
   inline      const subview<eT> operator()(const span& row_span, const span& col_span) const;
   
+  inline            subview<eT> operator()(const uword in_row1, const uword in_col1, const SizeMat& s);
+  inline      const subview<eT> operator()(const uword in_row1, const uword in_col1, const SizeMat& s) const;
+  
+  inline       subview<eT> head_rows(const uword N);
+  inline const subview<eT> head_rows(const uword N) const;
+  
+  inline       subview<eT> tail_rows(const uword N);
+  inline const subview<eT> tail_rows(const uword N) const;
+  
+  inline       subview<eT> head_cols(const uword N);
+  inline const subview<eT> head_cols(const uword N) const;
+  
+  inline       subview<eT> tail_cols(const uword N);
+  inline const subview<eT> tail_cols(const uword N) const;
   
   template<typename T1> arma_inline       subview_elem1<eT,T1> elem(const Base<uword,T1>& a);
   template<typename T1> arma_inline const subview_elem1<eT,T1> elem(const Base<uword,T1>& a) const;
   
+  template<typename T1> arma_inline       subview_elem1<eT,T1> operator()(const Base<uword,T1>& a);
+  template<typename T1> arma_inline const subview_elem1<eT,T1> operator()(const Base<uword,T1>& a) const;
+  
   
   template<typename T1, typename T2> arma_inline       subview_elem2<eT,T1,T2> elem(const Base<uword,T1>& ri, const Base<uword,T2>& ci);
   template<typename T1, typename T2> arma_inline const subview_elem2<eT,T1,T2> elem(const Base<uword,T1>& ri, const Base<uword,T2>& ci) const;
@@ -187,6 +241,7 @@ class Mat : public Base< eT, Mat<eT> >
   template<typename T1, typename T2> arma_inline       subview_elem2<eT,T1,T2> operator()(const Base<uword,T1>& ri, const Base<uword,T2>& ci);
   template<typename T1, typename T2> arma_inline const subview_elem2<eT,T1,T2> operator()(const Base<uword,T1>& ri, const Base<uword,T2>& ci) const;
   
+  
   template<typename T1> arma_inline       subview_elem2<eT,T1,T1> rows(const Base<uword,T1>& ri);
   template<typename T1> arma_inline const subview_elem2<eT,T1,T1> rows(const Base<uword,T1>& ri) const;
   
@@ -194,6 +249,11 @@ class Mat : public Base< eT, Mat<eT> >
   template<typename T2> arma_inline const subview_elem2<eT,T2,T2> cols(const Base<uword,T2>& ci) const;
   
   
+  arma_inline subview_each1< Mat<eT>, 0 > each_col();
+  arma_inline subview_each1< Mat<eT>, 1 > each_row();
+  
+  template<typename T1> inline subview_each2< Mat<eT>, 0, T1 > each_col(const Base<uword, T1>& indices);
+  template<typename T1> inline subview_each2< Mat<eT>, 1, T1 > each_row(const Base<uword, T1>& indices);
   
   arma_inline       diagview<eT> diag(const sword in_id = 0);
   arma_inline const diagview<eT> diag(const sword in_id = 0) const;
@@ -275,17 +335,19 @@ class Mat : public Base< eT, Mat<eT> >
   template<typename T1, typename T2, typename glue_type> inline const Mat& operator/=(const mtGlue<eT, T1, T2, glue_type>& X);
   
   
-  arma_inline arma_warn_unused eT& operator[] (const uword ii);
-  arma_inline arma_warn_unused eT  operator[] (const uword ii) const;
-  arma_inline arma_warn_unused eT& at         (const uword ii);
-  arma_inline arma_warn_unused eT  at         (const uword ii) const;
-  arma_inline arma_warn_unused eT& operator() (const uword ii);
-  arma_inline arma_warn_unused eT  operator() (const uword ii) const;
+  arma_inline arma_warn_unused const eT& at_alt     (const uword ii) const;
   
-  arma_inline arma_warn_unused eT& at         (const uword in_row, const uword in_col);
-  arma_inline arma_warn_unused eT  at         (const uword in_row, const uword in_col) const;
-  arma_inline arma_warn_unused eT& operator() (const uword in_row, const uword in_col);
-  arma_inline arma_warn_unused eT  operator() (const uword in_row, const uword in_col) const;
+  arma_inline arma_warn_unused       eT& operator[] (const uword ii);
+  arma_inline arma_warn_unused const eT& operator[] (const uword ii) const;
+  arma_inline arma_warn_unused       eT& at         (const uword ii);
+  arma_inline arma_warn_unused const eT& at         (const uword ii) const;
+  arma_inline arma_warn_unused       eT& operator() (const uword ii);
+  arma_inline arma_warn_unused const eT& operator() (const uword ii) const;
+  
+  arma_inline arma_warn_unused       eT& at         (const uword in_row, const uword in_col);
+  arma_inline arma_warn_unused const eT& at         (const uword in_row, const uword in_col) const;
+  arma_inline arma_warn_unused       eT& operator() (const uword in_row, const uword in_col);
+  arma_inline arma_warn_unused const eT& operator() (const uword in_row, const uword in_col) const;
   
   arma_inline const Mat& operator++();
   arma_inline void       operator++(int);
@@ -300,6 +362,9 @@ class Mat : public Base< eT, Mat<eT> >
   arma_inline arma_warn_unused bool is_square() const;
        inline arma_warn_unused bool is_finite() const;
   
+  inline arma_warn_unused bool is_sorted(const char* direction = "ascend")       const;
+  inline arma_warn_unused bool is_sorted(const char* direction, const uword dim) const;
+  
   arma_inline arma_warn_unused bool in_range(const uword ii) const;
   arma_inline arma_warn_unused bool in_range(const span& x ) const;
   
@@ -308,6 +373,8 @@ class Mat : public Base< eT, Mat<eT> >
   arma_inline arma_warn_unused bool in_range(const uword   in_row, const span& col_span) const;
   arma_inline arma_warn_unused bool in_range(const span& row_span, const span& col_span) const;
   
+  arma_inline arma_warn_unused bool in_range(const uword in_row, const uword in_col, const SizeMat& s) const;
+  
   arma_inline arma_warn_unused       eT* colptr(const uword in_col);
   arma_inline arma_warn_unused const eT* colptr(const uword in_col) const;
   
@@ -330,11 +397,23 @@ class Mat : public Base< eT, Mat<eT> >
   
   inline void   resize(const uword in_elem);
   inline void   resize(const uword in_rows, const uword in_cols);
-  inline void  reshape(const uword in_rows, const uword in_cols, const uword dim = 0);
+  
+  inline void  reshape(const uword in_rows, const uword in_cols);
+  inline void  reshape(const uword in_rows, const uword in_cols, const uword dim);
+  
+  
+  template<typename functor>
+  inline const Mat& transform(functor F);
+  
+  template<typename functor>
+  inline const Mat& imbue(functor F);
   
   
   arma_hot inline const Mat& fill(const eT val);
   
+  template<typename fill_type>
+  arma_hot inline const Mat& fill(const fill::fill_class<fill_type>& f);
+  
   inline const Mat& zeros();
   inline const Mat& zeros(const uword in_elem);
   inline const Mat& zeros(const uword in_rows, const uword in_cols);
@@ -441,11 +520,93 @@ class Mat : public Base< eT, Mat<eT> >
     arma_aligned       uword    col;
     };
   
-  inline       iterator begin();
-  inline const_iterator begin() const;
   
-  inline       iterator end();
-  inline const_iterator end()   const;
+  class const_row_col_iterator;
+
+  class row_col_iterator
+    {
+    public:
+    
+    inline row_col_iterator();
+    inline row_col_iterator(const row_col_iterator& in_it);
+    inline row_col_iterator(Mat<eT>& in_M, const uword row = 0, const uword col = 0);
+    
+    inline arma_hot eT& operator*();
+    
+    inline arma_hot row_col_iterator& operator++();
+    inline arma_hot row_col_iterator  operator++(int);
+    inline arma_hot row_col_iterator& operator--();
+    inline arma_hot row_col_iterator  operator--(int);
+    
+    inline uword row() const;
+    inline uword col() const;
+    
+    inline arma_hot bool operator==(const       row_col_iterator& rhs) const;
+    inline arma_hot bool operator!=(const       row_col_iterator& rhs) const;
+    inline arma_hot bool operator==(const const_row_col_iterator& rhs) const;
+    inline arma_hot bool operator!=(const const_row_col_iterator& rhs) const;
+    
+    // So that we satisfy the STL iterator types.
+    typedef std::bidirectional_iterator_tag iterator_category;
+    typedef eT                              value_type;
+    typedef uword                           difference_type; // not certain on this one
+    typedef const eT*                       pointer;
+    typedef const eT&                       reference;
+    
+    arma_aligned Mat<eT>* M;
+    
+    arma_aligned eT*    current_pos;
+    arma_aligned uword  internal_col;
+    arma_aligned uword  internal_row;
+    };
+  
+  
+  class const_row_col_iterator
+    {
+    public:
+    
+    inline const_row_col_iterator();
+    inline const_row_col_iterator(const       row_col_iterator& in_it);
+    inline const_row_col_iterator(const const_row_col_iterator& in_it);
+    inline const_row_col_iterator(const Mat<eT>& in_M, const uword row = 0, const uword col = 0);
+    
+    inline arma_hot const eT& operator*() const;
+    
+    inline arma_hot const_row_col_iterator& operator++();
+    inline arma_hot const_row_col_iterator  operator++(int);
+    inline arma_hot const_row_col_iterator& operator--();
+    inline arma_hot const_row_col_iterator  operator--(int);
+    
+    inline uword row() const;
+    inline uword col() const;
+    
+    inline arma_hot bool operator==(const const_row_col_iterator& rhs) const;
+    inline arma_hot bool operator!=(const const_row_col_iterator& rhs) const;
+    inline arma_hot bool operator==(const       row_col_iterator& rhs) const;
+    inline arma_hot bool operator!=(const       row_col_iterator& rhs) const;
+    
+    // So that we satisfy the STL iterator types.
+    typedef std::bidirectional_iterator_tag iterator_category;
+    typedef eT                              value_type;
+    typedef uword                           difference_type; // not certain on this one
+    typedef const eT*                       pointer;
+    typedef const eT&                       reference;
+    
+    arma_aligned const Mat<eT>* M;
+    
+    arma_aligned const eT*    current_pos;
+    arma_aligned       uword  internal_col;
+    arma_aligned       uword  internal_row;
+    };
+  
+  
+  inline       iterator  begin();
+  inline const_iterator  begin() const;
+  inline const_iterator cbegin() const;
+  
+  inline       iterator  end();
+  inline const_iterator  end() const;
+  inline const_iterator cend() const;
   
   inline       col_iterator begin_col(const uword col_num);
   inline const_col_iterator begin_col(const uword col_num) const;
@@ -459,12 +620,24 @@ class Mat : public Base< eT, Mat<eT> >
   inline       row_iterator end_row  (const uword row_num);
   inline const_row_iterator end_row  (const uword row_num) const;
   
+  inline       row_col_iterator begin_row_col();
+  inline const_row_col_iterator begin_row_col() const;
+  
+  inline       row_col_iterator end_row_col();
+  inline const_row_col_iterator end_row_col() const;
+  
+  
   inline void  clear();
   inline bool  empty() const;
   inline uword size()  const;
   
+  inline void swap(Mat& B);
+  
   inline void steal_mem(Mat& X);  //!< don't use this unless you're writing code internal to Armadillo
   
+  inline void steal_mem_col(Mat& X, const uword max_n_rows);
+  
+  
   template<uword fixed_n_rows, uword fixed_n_cols> class fixed;
   
   
@@ -476,7 +649,8 @@ class Mat : public Base< eT, Mat<eT> >
   inline void init(const std::string& text);
   
   #if defined(ARMA_USE_CXX11)
-  inline void init(const std::initializer_list<eT>& list);
+    inline void init(const std::initializer_list<eT>& list);
+    inline void init(const std::initializer_list< std::initializer_list<eT> >& list);
   #endif
   
   template<typename T1, typename T2>
@@ -514,7 +688,7 @@ class Mat<eT>::fixed : public Mat<eT>
   static const uword fixed_n_elem = fixed_n_rows * fixed_n_cols;
   static const bool  use_extra    = (fixed_n_elem > arma_config::mat_prealloc);
   
-  arma_aligned eT mem_local_extra[ (use_extra) ? fixed_n_elem : 1 ];
+  arma_align_mem eT mem_local_extra[ (use_extra) ? fixed_n_elem : 1 ];
   
   
   public:
@@ -526,7 +700,7 @@ class Mat<eT>::fixed : public Mat<eT>
   
   static const bool is_col = (fixed_n_cols == 1) ? true : false;
   static const bool is_row = (fixed_n_rows == 1) ? true : false;
-
+  
   static const uword n_rows = fixed_n_rows;
   static const uword n_cols = fixed_n_cols;
   static const uword n_elem = fixed_n_elem;
@@ -534,6 +708,7 @@ class Mat<eT>::fixed : public Mat<eT>
   arma_inline fixed();
   arma_inline fixed(const fixed<fixed_n_rows, fixed_n_cols>& X);
   
+  template<typename fill_type>       inline fixed(const fill::fill_class<fill_type>& f);
   template<typename T1>              inline fixed(const Base<eT,T1>& A);
   template<typename T1, typename T2> inline fixed(const Base<pod_type,T1>& A, const Base<pod_type,T2>& B);
   
@@ -546,26 +721,46 @@ class Mat<eT>::fixed : public Mat<eT>
   using Mat<eT>::operator();
   
   #if defined(ARMA_USE_CXX11)
-  inline                fixed(const std::initializer_list<eT>& list);
-  inline const Mat& operator=(const std::initializer_list<eT>& list);
+    inline                fixed(const std::initializer_list<eT>& list);
+    inline const Mat& operator=(const std::initializer_list<eT>& list);
+    
+    inline                fixed(const std::initializer_list< std::initializer_list<eT> >& list);
+    inline const Mat& operator=(const std::initializer_list< std::initializer_list<eT> >& list);
   #endif
   
+  arma_inline const Mat& operator=(const fixed<fixed_n_rows, fixed_n_cols>& X);
   
-  arma_inline arma_warn_unused eT& operator[] (const uword i);
-  arma_inline arma_warn_unused eT  operator[] (const uword i) const;
-  arma_inline arma_warn_unused eT& at         (const uword i);
-  arma_inline arma_warn_unused eT  at         (const uword i) const;
-  arma_inline arma_warn_unused eT& operator() (const uword i);
-  arma_inline arma_warn_unused eT  operator() (const uword i) const;
+  #if defined(ARMA_GOOD_COMPILER)
+    template<typename T1,              typename   eop_type> inline const Mat& operator=(const   eOp<T1,       eop_type>& X);
+    template<typename T1, typename T2, typename eglue_type> inline const Mat& operator=(const eGlue<T1, T2, eglue_type>& X);
+  #endif
   
-  arma_inline arma_warn_unused eT& at         (const uword in_row, const uword in_col);
-  arma_inline arma_warn_unused eT  at         (const uword in_row, const uword in_col) const;
-  arma_inline arma_warn_unused eT& operator() (const uword in_row, const uword in_col);
-  arma_inline arma_warn_unused eT  operator() (const uword in_row, const uword in_col) const;
+  arma_inline const Op< Mat_fixed_type, op_htrans >  t() const;
+  arma_inline const Op< Mat_fixed_type, op_htrans > ht() const;
+  arma_inline const Op< Mat_fixed_type, op_strans > st() const;
+  
+  arma_inline arma_warn_unused const eT& at_alt     (const uword i) const;
+  
+  arma_inline arma_warn_unused       eT& operator[] (const uword i);
+  arma_inline arma_warn_unused const eT& operator[] (const uword i) const;
+  arma_inline arma_warn_unused       eT& at         (const uword i);
+  arma_inline arma_warn_unused const eT& at         (const uword i) const;
+  arma_inline arma_warn_unused       eT& operator() (const uword i);
+  arma_inline arma_warn_unused const eT& operator() (const uword i) const;
+  
+  arma_inline arma_warn_unused       eT& at         (const uword in_row, const uword in_col);
+  arma_inline arma_warn_unused const eT& at         (const uword in_row, const uword in_col) const;
+  arma_inline arma_warn_unused       eT& operator() (const uword in_row, const uword in_col);
+  arma_inline arma_warn_unused const eT& operator() (const uword in_row, const uword in_col) const;
+  
+  arma_inline arma_warn_unused       eT* colptr(const uword in_col);
+  arma_inline arma_warn_unused const eT* colptr(const uword in_col) const;
   
   arma_inline arma_warn_unused       eT* memptr();
   arma_inline arma_warn_unused const eT* memptr() const;
   
+  arma_inline arma_warn_unused bool is_vec() const;
+  
   arma_hot inline const Mat<eT>& fill(const eT val);
   arma_hot inline const Mat<eT>& zeros();
   arma_hot inline const Mat<eT>& ones();
